package
Version:
v0.0.0-...-5ed7928
Opens a new window with list of versions in this module.
Published: Nov 24, 2023
License: LGPL-2.1
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Map[T any, O any](arr []T, mapper func(T) O) []O
func Reduce[T any, O any](arr []T, init O, f func(O, T) O) O
func Zip[T any](arr ...[]T) [][]T
Source Files
¶
Click to show internal directories.
Click to hide internal directories.